/* CSS overrides for the rendermd page */

/* the render container should match the notebook container*/
#render-container {
  padding: 15px;
  -moz-box-shadow: 0 0 12px 1px rgba(87, 87, 87, 0.2);
  -webkit-box-shadow: 0 0 12px 1px rgba(87, 87, 87, 0.2);
  box-shadow: 0 0 12px 1px rgba(87, 87, 87, 0.2);
  min-height: calc(100% - 30px);
}

/* rendermd-page-title-wrap and rendermd-page-title
   are styled to match the notebook save widget */
.rendermd-page-title-wrap {
    margin-top: 6px;
}

.rendermd-page-title {
    height: 1em;
    line-height: 1em;
    padding: 3px;
    margin-left: 16px;
    border: none;
    font-size: 146.5%;
    border-radius: 2px;
}

.rendered_html p img:not(:only-child),
.rendered_html p a:not(:only-child) img {
  display: inline;
}

.rendered_html pre {
  background-color: #f5f5f5;
  padding: 4px;
}

.rendered_html code {
  background-color: #f9f2f4;
  padding: 2px 4px;
}

.rendered_html pre code {
  background-color: transparent;
  padding: 0;
}

.rendered_html ol li,
.rendered_html ul li {
  margin-bottom: 0.5em;
}

* + .embed-responsive {
    margin-top: 1em;
}

/* bootstrap's embed-responsive-item class, as applied to images */
.embed-responsive > img {
  position: absolute;
  top: 0;
  left: 0;
  bottom: 0;
  height: 100%;
  width: 100%;
  border: 0;
}

.embed-responsive > a {
    content: "";
    position: absolute;
    top: 37.5%;
    left: 37.5%;
    right: 37.5%;
    bottom: 37.5%;
    z-index: 100;
    background: transparent url(video_play.svg) no-repeat center;
    background-size: contain;
}

.embed-responsive > a:hover {
  top: 35%;
  left: 35%;
  right: 35%;
  bottom: 35%;
}
